@@ -156,3 +156,67 @@ class TestSourcesWithOrgID(unittest.TestCase):
         )
 
         self.assertEqual(delete['message'], 'Success', delete)
+
+    def test_rename_datset(self):
+        export = self.sources.static_file_upload(
+            org_id=test_org,
+            name=str(uuid.uuid4()),
+            content="tests/data_test.csv"
+        )
+
+        try:
+            _ = self.sources.update_dataset_metadata(
+                org_id=test_org,
+                dataset_id=export["id"],
+                name="{}__renamed".format(str(uuid.uuid4()))
+            )
+            self.assertTrue(True, "Pipeline was renamed")
+        except Exception as e:
+            self.assertTrue(False, e)
+
+    def test_add_facets_datset(self):
+        export = self.sources.static_file_upload(
+            org_id=test_org,
+            name=str(uuid.uuid4()),
+            content="tests/data_test.csv"
+        )
+
+        try:
+            _ = self.sources.update_dataset_metadata(
+                org_id=test_org,
+                dataset_id=export["id"],
+                facets=[str(uuid.uuid4())[:10]]
+            )
+            self.assertTrue(True, "Facets were added to dataset")
+        except Exception as e:
+            self.assertTrue(False, e)
+
+    def test_add_description_datset(self):
+        export = self.sources.static_file_upload(
+            org_id=test_org,
+            name=str(uuid.uuid4()),
+            content="tests/data_test.csv"
+        )
+
+        try:
+            _ = self.sources.update_dataset_metadata(
+                org_id=test_org,
+                dataset_id=export["id"],
+                description="{}__renamed".format(str(uuid.uuid4()))
+            )
+            self.assertTrue(True, "Description was added to dataset")
+        except Exception as e:
+            self.assertTrue(False, e)
+
+    def test_utf_encoding_source(self):
+        try:
+            _ = self.sources.static_file_upload(
+                org_id=test_org,
+                name=str(uuid.uuid4()),
+                content="tests/data_test.csv",
+                encoding="UTF-8"
+
+            )
+            self.assertTrue(True, "Dataset was created")
+        except Exception as e:
+            self.assertTrue(False, e)
