@@ -245,9 +245,7 @@ class ApiManager:
         :return:
         """
         try:
-            sources = self.pipelines.get_pipelines_v2(org_id=org_id)
-
-            return sources["pipelineSummaries"]
+            return self.pipelines.get_pipelines_v2(org_id=org_id)
 
         except Exception as error:
             raise error
@@ -590,9 +588,9 @@ class ApiManager:
 
         for source in sources:
             if self.evergreen_enabled:
-                source_id_to_data[source["id"]] = source
+                source_id_to_data[source["id"]["id"]] = source
             else:
-                source_id_to_data[source["id"]] = source
+                source_id_to_data[source["id"]["id"]] = source
 
         pipeline_info = self.pipelines.get_pipeline(org_id=org_id, pipeline_id=pipeline_id)
 
