@@ -72,6 +72,8 @@ class ApiRequestManager:
             }
         )
 
+        self.gql_url = self.props.get_remote(self.cluster) + "artifacts/graphql"
+
     def close_session(self):
         """
         Closes request session
@@ -140,6 +142,17 @@ class ApiRequestManager:
 
             raise error
 
+    def graph_ql_query(self, org_id, query):
+        header = self.build_header(org_id=org_id)
+
+        query_results = self.session.post(
+            self.gql_url,
+            headers=header,
+            data=query
+        )
+
+        return query_results
+
     def build_header(self, aut_token=None, org_id=None, others=None):
         """
         Creates request header
