@@ -37,7 +37,7 @@ class AssetAccess(ApiRequestManager):
         :param orgid: Organization id
         :type orgid: int or str
         """
-        super().__init__(cluster=cluster, props=props)
+        super().__init__(cluster=cluster, props=props, org_id=orgid)
 
         required = {'psycopg2-binary'}
         installed = {pkg.key for pkg in pkg_resources.working_set}
