@@ -23,15 +23,15 @@ import json_lines
 from unify.properties import Properties
 from unify.properties import ClusterSetting
 from unify.apirequestsmng import ApiRequestManager
+from unify.helpers.SingleOrg import single_org
 
 
 class Graph(ApiRequestManager):
-
     """
     Class to interact with pipeline endpoints
     """
 
-    def __init__(self, cluster=None, props=Properties(ClusterSetting.KEY_RING)):
+    def __init__(self, cluster=None, props=Properties(ClusterSetting.KEY_RING), org_id=None):
 
         """
         Class constructor
@@ -41,7 +41,7 @@ class Graph(ApiRequestManager):
         :param props: Properties instantiated object
         :type props: class:`unify.properties.Properties`
         """
-        super().__init__(cluster=cluster, props=props)
+        super().__init__(cluster=cluster, props=props, org_id=org_id)
 
         self.session.headers.update(
             {
@@ -55,10 +55,11 @@ class Graph(ApiRequestManager):
 
         self.graph_query_url = self.graph_url + "/{}/query"
 
-    def get_graphs_list(self, org_id):
-
+    @single_org
+    def get_graphs_list(self, org_id=None):
         """
         Retrieves the list of graphs on the given org
+
         :param org_id: organization Id to be queried
         :return: Array containing list of graphs data
         """
@@ -75,10 +76,11 @@ class Graph(ApiRequestManager):
 
         raise Exception(repr(result.content))
 
-    def query_graph(self, org_id, graph, query, json_format=False):
-
+    @single_org
+    def query_graph(self, org_id=None, *, graph, query, json_format=False):
         """
         Runs a cypher query on the given graph
+
         :param org_id: Organization id where the graph is stored
         :param graph: Graph id to be queried
         :param query: Cypher query
