@@ -29,6 +29,7 @@ from .generalutils import create_schema_dataset
 from .generalutils import stream_iterable
 from .WaitingLibrary import Wait
 from unify.helpers.SingleOrg import single_org
+from unify.helpers.graph_ql.dataset_gql import DatasetGrapql
 
 
 class Sources(ApiRequestManager):
@@ -99,6 +100,8 @@ class Sources(ApiRequestManager):
             self.dataset_info_url = self.props.get_remote(
                 self.cluster) + "tags/org/{}/pipelines/v2/datasets"
 
+            self.gql_builder = DatasetGrapql()
+
         except Exception as error:
             raise error
 
@@ -248,7 +251,7 @@ class Sources(ApiRequestManager):
 
         data = content.encode(encoding)
 
-        jdata = csv_to_json(data)
+        jdata = csv_to_json(data, encoding=encoding)
 
         first = True
 
@@ -264,7 +267,7 @@ class Sources(ApiRequestManager):
 
                 file_dir, path = mkstemp(suffix=".csv")
 
-                open(path, "w+").write(json_to_csv(aux_file))
+                open(path, "w", encoding=encoding).write(json_to_csv(aux_file))
 
                 dataset_data["create"] = self.create_api_data_set(
                     name=name,
@@ -289,7 +292,7 @@ class Sources(ApiRequestManager):
 
                 file_dir, path2 = mkstemp(suffix=".csv")
 
-                open(path2, "wb").write(json_to_csv(aux_file).encode(encoding))
+                open(path2, "w", encoding=encoding).write(json_to_csv(aux_file))
 
                 try:
                     added_data = self.add_data_to_existing_source(
@@ -490,7 +493,7 @@ class Sources(ApiRequestManager):
         id_to_type = {}
 
         for dataset in datasets:
-            id_to_type[dataset["id"]] = dataset
+            id_to_type[dataset["id"]["id"]] = dataset
 
         all_datasets = []
         for dataset_id in dataset_ids:
@@ -502,15 +505,17 @@ class Sources(ApiRequestManager):
 
             source_type = "Upload"
 
-            if "ean.source_type" in info["fields"]:
-                source_type = info["fields"]["ean.source_type"]
+            if "labels" in info:
+                if "raw" in info["labels"]:
+                    if "ean_source_type" in info["labels"]["raw"]:
+                        source_type = info["labels"]["raw"]["ean_source_type"]
 
             get_source_request = self.download_dataset_content(org_id=org_id, dataset_id=dataset_id)
 
             result = {
                 "component": None,
                 "id": dataset_id,
-                "schema": info["fields"]["schema"],
+                "schema": info["schema"],
                 "name": id_to_type[dataset_id]["name"],
                 "type": source_type,
                 "file_content": csv_to_json(csv_data=get_source_request)
@@ -567,7 +572,7 @@ class Sources(ApiRequestManager):
     @single_org
     def overwrite_dataset(
             self, org_id=None, *, data_set_id, file_path, group_id=None,
-            format="csv", convert_to_parquet="false", encoding="utf-8 "):
+            format="csv", convert_to_parquet="false", encoding="utf-8", encode=True):
 
         """
         Overwrites the contents of the given dataset with new content.
@@ -604,7 +609,8 @@ class Sources(ApiRequestManager):
             group_id=group_id,
             format=format,
             convert_to_parquet=convert_to_parquet,
-            encoding=encoding
+            encoding=encoding,
+            encode=encode
         )
 
         response["append"] = self.append_command(
@@ -745,7 +751,7 @@ class Sources(ApiRequestManager):
 
     def stage_data(
             self, name, org_id, file_path, group_id=None, format="csv",
-            convert_to_parquet="false", encoding='UTF-8', encode=False):
+            convert_to_parquet="false", encoding='UTF-8', encode=True):
         """
         Stages data to a given org and group id.
 
@@ -789,7 +795,10 @@ class Sources(ApiRequestManager):
                 "groupId": group_id
             }
 
-        file_data = open(file_path, "r").read().encode(encoding)
+        if encode:
+            file_data = open(file_path, "r").read().encode(encoding)
+        else:
+            file_data = file_path.encode(encoding)
 
         test_request = self.session.post(
             self.stage_file_url,
@@ -973,7 +982,7 @@ class Sources(ApiRequestManager):
         raise Exception(repr(post_upload_pitag.content))
 
     @single_org
-    def static_file_upload(self, name, content, org_id=None, params=None):
+    def static_file_upload(self, name, content, org_id=None, params=None, encoding=None):
         """
         :param name: Dataset name to be created
         :type name: str
@@ -987,7 +996,11 @@ class Sources(ApiRequestManager):
 
         static_file_upload_url = self.staticfile_upload_url
 
-        query_strings = {"name": str(name)}
+        query_strings = {
+            "name": str(name)
+        }
+        if encoding:
+            query_strings["charset"] = encoding
 
         headers = self.build_header(
             org_id=org_id
@@ -1022,26 +1035,24 @@ class Sources(ApiRequestManager):
         :return:
         """
 
-        header = self.build_header(
-            org_id=org_id,
-            others=self.delete_content_type_header
-        )
+        query = self.gql_builder.build_dataset_query()
 
-        query_strings = {
-            "ean.orgs": org_id,
-            "_fields": "schema,ean.ready,ean.source_type,ean.facets,ean.description,ean.dataArchiveServerName"
+        get_sources_request = self.graph_ql_query(org_id=org_id, query=query)
+
+        if get_sources_request.status_code in range(200, 203):
+            data = json.loads(get_sources_request.content)
+
+            if "data" in data:
+                if "artifacts" in data["data"]:
+                    return data["data"]["artifacts"]
+
+            return []
+        error_message = {
+            "message": repr(get_sources_request.content),
+            "code": get_sources_request.status_code
         }
 
-        get_sources_request = self.session.get(
-            self.labeling_sources_2,
-            headers=header,
-            params=query_strings
-        )
-
-        if get_sources_request.status_code in [200, 201, 202]:
-            return json.loads(get_sources_request.content.decode('utf8'))
-
-        raise Exception(repr(get_sources_request.content))
+        raise Exception(json.dumps(error_message))
 
     def get_sources_by_labels(self, org_id, facets):
         """
@@ -1054,25 +1065,20 @@ class Sources(ApiRequestManager):
         :return:
         """
 
-        header = self.build_header(
-            org_id=org_id,
-            others=self.delete_content_type_header
+        query = self.gql_builder.build_dataset_query(
+            facets=facets
         )
 
-        query_strings = {
-            "facet": facets
-        }
+        get_sources_request = self.graph_ql_query(org_id=org_id, query=query)
 
-        get_sources_request = self.session.get(
-            self.labeling_sources_facets_url,
-            headers=header,
-            params=query_strings
-        )
+        if get_sources_request.status_code in range(200, 203):
+            data = json.loads(get_sources_request.content)
 
-        content = json.loads(get_sources_request.content)
+            if "data" in data:
+                if "artifacts" in data["data"]:
+                    return data["data"]["artifacts"]
 
-        if get_sources_request.status_code == 200:
-            return content
+            return []
 
         raise Exception(repr(get_sources_request.content))
 
@@ -1103,7 +1109,7 @@ class Sources(ApiRequestManager):
             headers=headers
         )
 
-        if delete_request.status_code in [200, 201]:
+        if delete_request.status_code in range(200, 203):
             return json.loads(delete_request.content)
 
         raise Exception(json.loads(delete_request.content))
@@ -1190,3 +1196,29 @@ class Sources(ApiRequestManager):
                 org_id=org_id,
                 params=[('sheetName', sheet_name)]
             )
+
+    @single_org
+    def update_dataset_metadata(self, org_id=None, *, dataset_id=None, name=None, description=None, facets=None):
+        """
+        Method to update a dataset's metadata
+        :param org_id: org id where the pipeline is stored
+        :param dataset_id: id of the pipeline to be edited
+        :param name: new pipeline name
+        :param description: description to be added
+        :param facets:
+        :return:
+        """
+
+        query = self.gql_builder.mutation_query(
+            dataset_id=str(dataset_id),
+            new_name=name,
+            description=description,
+            facets=facets
+        )
+
+        response = self.graph_ql_query(org_id=org_id, query=query)
+
+        if response.status_code in [200, 201, 202]:
+            return json.loads(response.content)
+
+        raise Exception(repr(response.content))
