@@ -22,6 +22,7 @@ from unify.properties import Properties
 from unify.properties import ClusterSetting
 from unify.apirequestsmng import ApiRequestManager
 from unify.generalutils import csv_to_json
+from unify.helpers.SingleOrg import single_org
 
 
 class Templates(ApiRequestManager):
@@ -29,7 +30,7 @@ class Templates(ApiRequestManager):
     Template client class to interact with templates endpoints
     """
 
-    def __init__(self, cluster=None, props=Properties(ClusterSetting.KEY_RING)):
+    def __init__(self, cluster=None, props=Properties(ClusterSetting.KEY_RING), org_id=None):
         """
         Template constructor
 
@@ -38,7 +39,7 @@ class Templates(ApiRequestManager):
         :param props: Instantiated Properties class
         :type props: class:`unify.properties.Properties`
         """
-        super().__init__(cluster=cluster, props=props)
+        super().__init__(cluster=cluster, props=props, org_id=org_id)
 
         try:
 
@@ -85,7 +86,8 @@ class Templates(ApiRequestManager):
         except Exception as error:
             raise error
 
-    def upload_template(self, file_path, org_id):
+    @single_org
+    def upload_template(self, file_path, org_id=None):
         """
         Uploads the given file path with templates data.
 
@@ -116,7 +118,8 @@ class Templates(ApiRequestManager):
 
         raise Exception(post_upload_template.content)
 
-    def get_attributes(self, org_id, template_id):
+    @single_org
+    def get_attributes(self, org_id=None, template_id=None):
         """
         Downloads all the attributes of the given template id.
 
@@ -143,7 +146,8 @@ class Templates(ApiRequestManager):
 
         raise Exception(repr(get_attrs.content))
 
-    def upload_string_content_file(self, org_id, content):
+    @single_org
+    def upload_string_content_file(self, org_id=None, content=None):
         """
         Uploads templates data that are stored in the variable content.
 
@@ -171,7 +175,8 @@ class Templates(ApiRequestManager):
 
         raise Exception(post_upload_template.content)
 
-    def upload_config(self, org_id, file_path):
+    @single_org
+    def upload_config(self, org_id=None, file_path=None):
         """
         Uploads template configuration file.
 
@@ -182,16 +187,23 @@ class Templates(ApiRequestManager):
         :return: Upload template configuration status message
         """
         try:
+
             file_reader = open(file_path, "r+")
-            content = file_reader.read()
+            try:
+                content = file_reader.read()
+
+            except Exception as e:
+                file_reader.close()
+                raise Exception(str(e))
+            finally:
+                file_reader.close()
         except FileNotFoundError:
-            print('File does not exist')
-        finally:
-            file_reader.close()
+            raise FileNotFoundError("File {} does not exist".format(file_path))
 
         return self.upload_config_with_content(org_id, content)
 
-    def upload_config_with_content(self, org_id, content, format="csv"):
+    @single_org
+    def upload_config_with_content(self, org_id=None, content=None, format="csv"):
         """
         Uploads template configuration from content of a variable and not a file.
 
@@ -227,7 +239,8 @@ class Templates(ApiRequestManager):
 
         raise Exception(post_upload_template.content)
 
-    def _add_category(self, org_id, category):
+    @single_org
+    def _add_category(self, org_id=None, category=None):
         url = self.categories_url.format(org_id)
         headers = self.build_header(
             org_id=org_id,
@@ -246,7 +259,8 @@ class Templates(ApiRequestManager):
             return json.loads(request.content)
         raise Exception(request.content)
 
-    def list_all_categories(self, org_id):
+    @single_org
+    def list_all_categories(self, org_id=None):
         """
         Retrieves all the template categories on the given org.
 
@@ -270,7 +284,8 @@ class Templates(ApiRequestManager):
             return entries_dic
         raise Exception(request.content)
 
-    def category(self, org_id, template_id, template_name, version, categories):
+    @single_org
+    def category(self, org_id=None, *, template_id, template_name, version, categories):
         """
         Updates template categories
 
@@ -317,9 +332,10 @@ class Templates(ApiRequestManager):
 
         raise Exception(request.content)
 
-    def get_template(self, org_id, template_id):
+    @single_org
+    def get_template(self, org_id=None, *, template_id):
         """
-        Retrives template by id.
+        Retrieves template by id.
 
         :param org_id: Org id of whom templates are being retrieved
         :type org_id: int or str
@@ -338,9 +354,10 @@ class Templates(ApiRequestManager):
 
         raise Exception(json.loads(request.content))
 
-    def list_asset_templates(self, org_id):
+    @single_org
+    def list_asset_templates(self, org_id=None):
         """
-        Retrives the templates list from the given org.
+        Retrieves the templates list from the given org.
 
         :param org_id: Org id of whom templates are being retrieved
         :type org_id: int or str
@@ -358,7 +375,8 @@ class Templates(ApiRequestManager):
 
         raise Exception(json.loads(list_request.content))
 
-    def download_template(self, org_id, list_templates=None):
+    @single_org
+    def download_template(self, org_id=None, list_templates=None):
         """
         Downloads the templates data.
 
@@ -369,6 +387,8 @@ class Templates(ApiRequestManager):
         :return: Text representing templates
         """
 
+        if list_templates is None:
+            list_templates = []
         list_templates = list_templates if list_templates is not None else []
 
         header = self.build_header(
@@ -385,7 +405,8 @@ class Templates(ApiRequestManager):
 
         raise Exception(json.loads(get_response.content))
 
-    def download_all_templates(self, org_id, format="csv"):
+    @single_org
+    def download_all_templates(self, org_id=None, format="csv"):
         """
         Retrieves all the templates data.
 
@@ -410,7 +431,8 @@ class Templates(ApiRequestManager):
         except Exception as error:
             raise error
 
-    def download_all_template_config(self, org_id):
+    @single_org
+    def download_all_template_config(self, org_id=None):
         """
         Retrieves all template configurations.
 
@@ -463,7 +485,8 @@ class Templates(ApiRequestManager):
         except Exception as error:
             raise error
 
-    def download_given_templates(self, org_id, template_list=None, format="csv"):
+    @single_org
+    def download_given_templates(self, org_id=None, template_list=None, format="csv"):
         """
         Downloads data from templates.
 
